@@ -72,6 +72,8 @@
 **             the pod2man translater.
 */
 
+#ifdef EAPI
+
 #ifndef AP_HOOK_H
 #define AP_HOOK_H
 
@@ -384,6 +386,8 @@ API_EXPORT(int)           ap_hook_use          (char *hook, ap_hook_sig sig, ap_
 API_EXPORT(int)           ap_hook_call         (char *hook, ...);
 
 #endif /* AP_HOOK_H */
+
+#endif /* EAPI */
 /*
 =pod
 ##
@@ -693,8 +697,8 @@ ap_ctx(3)
 
 =head1 HISTORY
 
-The ap_hook(3) interface was originally designed and implemented in October
-1998 by Ralf S. Engelschall as part of the mod_ssl project.
+The ap_hook(3) interface was originally designed and 
+implemented in October 1998 by Ralf S. Engelschall.
 
 =head1 AUTHOR
 
